%define	major	1
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname -d %{name}

Name:		gmic
Version:	1.6.0.1
Release:	%mkrel 1
Group:		Graphics/Utilities
# CeCILL version 2.0
License:	CeCILL
Summary:	A script language (G'MIC) dedicated to image processing
Url:		http://gmic.sourceforge.net
Source0:	http://download.sourceforge.net/gmic/%{name}_%{version}.tar.gz
Patch0:		gmic-1.6.0.1-makefile.patch
BuildRequires:	opencv-devel
BuildRequires:	graphicsmagick-devel
BuildRequires:	fftw-devel
BuildRequires:	gimp-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	qt4-devel
BuildRequires:  dos2unix

%description
G'MIC defines a complete image processing framework, and thus
can manage generic image data as other image-related tools.

Anyway, the specific features described below make it a bit particular :

* It internally works with lists of images.
  Image manipulations and interactions can be done
  either grouped or focused on specific items.
* It can process a wide variety of image types,
  including multi-spectral (arbitray number of channels)
  and 3d volumetric images, as well as image sequences,
  or 3d vector objects.
  Images with different pixel types are supported,
  allowing to process flawlessly images with 8bits or
  16bits integers per channel, as well as float-valued datasets.
* It provides small but efficient visualization modules
  dedicated to the exploration/viewing of 2d/3d multi-spectral images,
  3d vector objects (elevation map, isocurves, isosurfaces,...),
  or 1d graph plots.
* It proposes commands to handle custom interactive windows
  where events can be managed easily by the user.
* It is highly extensible through the importation of custom command
  files which add new commands that become understood by the
  language interpreter.
* Most of the functionalities can be used inside GIMP
  via the provided plug-in, allowing end-users to integrate
  any G'MIC-based pipeline directly in a nice GUI,
  without coding efforts.
* It is based on the latest development versions of the CImg Library,
  a well established C++ template image processing toolkit,
  developed by the same team of developers.

%files -f %{name}.lang
%doc COPYING README
%config(noreplace) %{_sysconfdir}/bash_completion.d/%{name}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.*

#------------------------------------------------------

%package -n zart
Summary:        GUI for G'MIC real-time manipulations on the output of a webcam
Group:          Graphics/Utilities
Provides:	%{name}-zart = %{version}-%{release}

%description -n zart
ZArt is a computer program whose purpose is to demonstrate the possibilities of
the G'MIC image processing language by offering the choice of several
manipulations on a video stream acquired from a webcam.

%files -n zart
%{_bindir}/zart
#%{_datadir}/zart/haarcascade*.xml

#------------------------------------------------------

%package -n gimp-plugin-%{name}
Summary:	gmic plugin for gimp
Group:		Graphics/Utilities
Requires:	gimp >= 2.6.0
Obsoletes:	%{name}-gimp < 1.5.1.5-1
Provides:	%{name}-gimp = %{version}-%{release}

%description -n gimp-plugin-%{name}
G'MIC has been made available as an easy-to-use plug-in for GIMP.
It extends this retouching software capabilities by offering a large number of
pre-defined image filters and effects.
Of course, the plug-in is highly customizable and it is possible to add your
own custom G'MIC-written filters in it.

%files -n gimp-plugin-%{name}
%{_libdir}/gimp/2.0/plug-ins/%{name}_gimp

#------------------------------------------------------

%package -n %libname
Summary:	Library for gmic
Group:		System/Libraries

%description -n %libname
This package contains the library needed to run programs
dynamically linked with gmic.

%files -n %libname
%{_libdir}/lib%{name}.so.%{major}*

#------------------------------------------------------

%package -n %develname
Summary:	Header file for gmic
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%{name}-gimp-devel < 1.5.1.5-1
Provides:	%{name}-devel = %{version}-%{release}

%description -n %develname
This package contains the development file for gmic.

%files -n %develname
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so

#------------------------------------------------------

%prep
%setup -q
dos2unix src/Makefile
%apply_patches

%build
%setup_compile_flags

pushd src
	%make
popd

pushd zart
	%qmake_qt4
	%make
popd

%install
pushd src
	%makeinstall_std LIB=%{_lib}
popd

pushd zart
	install -m 0755 zart %{buildroot}%{_bindir}/zart
popd

%find_lang %{name} --with-man


%changelog
* Thu Nov 20 2014 matteo <matteo> 1.6.0.1-1.mga5
+ Revision: 797964
- convert makefile line endings to unix format
- fix zart install
- fix lib installation path
- rediff/redo makefile patch
- new version 1.6.0.1

* Wed Oct 15 2014 umeabot <umeabot> 1.5.7.0-6.mga5
+ Revision: 744551
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.7.0-5.mga5
+ Revision: 679668
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.5.7.0-4.mga5
+ Revision: 666993
- rebuild for ilmbase and OpenEXR

* Thu May 01 2014 luigiwalser <luigiwalser> 1.5.7.0-3.mga5
+ Revision: 619151
- rebuild for ilmbase

* Sat Oct 19 2013 umeabot <umeabot> 1.5.7.0-2.mga4
+ Revision: 534522
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 wally <wally> 1.5.7.0-1.mga4
+ Revision: 478179
- new version 1.5.7.0
- rediff/redo makefile patch

* Thu Sep 12 2013 fwang <fwang> 1.5.5.0-7.mga4
+ Revision: 477935
- use correct ldflags

* Thu Sep 12 2013 fwang <fwang> 1.5.5.0-6.mga4
+ Revision: 477861
- rebuild for new openexr

* Sat Aug 24 2013 wally <wally> 1.5.5.0-5.mga4
+ Revision: 471410
- drop requires added in previous release as seems like libs aren't needed to run gmic/zart

* Sat Aug 24 2013 wally <wally> 1.5.5.0-4.mga4
+ Revision: 471356
- use find_lang macro
- add requires
- add .so file to devel pkg

* Sat Aug 24 2013 wally <wally> 1.5.5.0-3.mga4
+ Revision: 471333
- clean lib pkg requires/obsoletes/provides
- clean unneeded conflicts

* Mon Jun 03 2013 fwang <fwang> 1.5.5.0-2.mga4
+ Revision: 435939
- rebuild for new libpng

* Mon Mar 25 2013 matteo <matteo> 1.5.5.0-1.mga3
+ Revision: 405194
- new version

* Wed Feb 06 2013 matteo <matteo> 1.5.4.0-1.mga3
+ Revision: 394769
- new version

* Sat Jan 12 2013 umeabot <umeabot> 1.5.2.4-2.mga3
+ Revision: 351865
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + boklm <boklm>
    - Update group: Graphics/Other -> Graphics/Utilities

* Mon Dec 10 2012 matteo <matteo> 1.5.2.4-1.mga3
+ Revision: 329360
- new version

* Sun Dec 02 2012 fwang <fwang> 1.5.2.1-2.mga3
+ Revision: 325027
- rebuild for new openexr

* Sat Nov 03 2012 matteo <matteo> 1.5.2.1-1.mga3
+ Revision: 313458
- fixed subpackages group
- fixed group
- new version

* Tue Sep 04 2012 fwang <fwang> 1.5.1.9-2.mga3
+ Revision: 287848
- update ldflags

* Tue Sep 04 2012 matteo <matteo> 1.5.1.9-1.mga3
+ Revision: 287809
- new version

* Sat Aug 18 2012 matteo <matteo> 1.5.1.8-1.mga3
+ Revision: 281962
- new version

* Sat Jul 28 2012 matteo <matteo> 1.5.1.7-1.mga3
+ Revision: 275079
- new version

* Sat Jun 23 2012 matteo <matteo> 1.5.1.6-2.mga3
+ Revision: 262775
- added missing br graphicsmagick-devel
- removed gimp-plugin unnecessary requirement

* Fri Jun 22 2012 matteo <matteo> 1.5.1.6-1.mga3
+ Revision: 262700
- new upstream version 1.5.1.6

* Wed Jun 20 2012 matteo <matteo> 1.5.1.5-3.mga3
+ Revision: 262241
- fix obsoletes to solve dependencies error

* Tue Jun 19 2012 matteo <matteo> 1.5.1.5-2.mga3
+ Revision: 261831
- fix gmic and gimp-plugin-gmic descriptions
- fix unversioned provide (zart)
- remove old and unnecessary patches

* Mon Jun 18 2012 matteo <matteo> 1.5.1.5-1.mga3
+ Revision: 261822
- moved gimp requirement from gmic to gimp-plugin-gmic
- libname description improved
- imported package gmic

